@@ -18,15 +18,20 @@ class Storage(driver.Base):
         self._secret_key = config.jss_secretkey
         self._bucket = config.jss_bucket
         self._domain = config.jss_domain
-        print "==========================>"+config.jss_accesskey
+        print "==========================>access_key:"+config.jss_accesskey
+        print "==========================>jss_secretkey:"+config.jss_secretkey
+        print "==========================>jss_bucket:"+config.jss_bucket
+        print "==========================>jss_domain:"+config.jss_domain
+        
         self._jss = JssClient(self._access_key, self._secret_key, self._domain, "80")
         
     def _init_path(self, path=None):
         if path:
-            path.split("/")[2]
+            return path.split("/")[2]
         return path
 
     def content_redirect_url(self, path):
+        print "content_redirect_url path:"+path
         path = self._init_path(path)
         object_instance = self._jss.bucket(self._bucket).object(path)
         
@@ -35,7 +40,8 @@ class Storage(driver.Base):
     def get_json(self, path):
         try:
             return json.loads(self.get_unicode(path))
-        except:
+        except Exception as e:
+            print e
             return []
 
     @lru.get
@@ -46,13 +52,13 @@ class Storage(driver.Base):
         try:
             return self._jss.bucket(self._bucket).get_Key(path)
         except Exception as e:
+            print e
             raise e
 
     
     @lru.set
     def put_content(self, path, content):
-        print self
-        print path
+        print "put_content path:"+path
         path = self._init_path(path)
         try:
             object_instance = self._jss.bucket(self._bucket).object(path)
@@ -71,6 +77,7 @@ class Storage(driver.Base):
              object_instance = self._jss.bucket(self._bucket).object(path)
              object_instance.multi_upload_fp(None, None, fp, part_size)
         except Exception as e :
+            print e
             raise e
 
     @lru.remove
@@ -80,4 +87,5 @@ class Storage(driver.Base):
         try:
            self._jss.bucket(self._bucket).delete_key(path)
         except Exception as e:
+            print e
             raise e
